#include <fork.h>
#include <io.h>

extern async void pra( void );

sh int a[4] = { 2, 1, 3, 1 };
sh int shmemloc;

main(){
  start if ($<4) { 
    farm pra();
    a[$] = mpadd( &shmemloc, a[$]); 
    farm {
      int j;
      pra();
      for (j=0;j<100;j++); /*delay loop*/;
      if($==0) { prS("The sum is "); prIln( shmemloc ); }
    }
  }
}

void pra() {
 int i;
 for(i=0;i<8*$;i++); /*delay loop*/
 prIln( a[$]);
}
